@@ -1,5 +1,5 @@
 package NewsExtractor;
-our $VERSION = v0.0.1;
+our $VERSION = v0.0.2;
 use Moo;
 
 use Mojo::UserAgent;
@@ -7,6 +7,8 @@ use Mojo::UserAgent::Transactor;
 use Try::Tiny;
 
 use Types::URI qw< Uri >;
+
+use Importer 'NewsExtractor::TextUtil' => qw(u);
 use NewsExtractor::Error;
 use NewsExtractor::Download;
 
@@ -23,18 +25,21 @@ sub download {
 
     my $tx = $ua->get( "". $self->url );
 
-    my $res = try { $tx->result } catch {
+    my $res;
+    try {
+        $res = $tx->result
+    } catch {
         $error = NewsExtractor::Error->new(
             is_exception => 0,
-            message => $_
-        );
+            message => u($_),
+        )
     };
 
     if ($res) {
         if ($res->is_error) {
             $error = NewsExtractor::Error->new(
                 is_exception => 0,
-                message => $res->message,
+                message => u($res->message),
             );
         } else {
             $download = NewsExtractor::Download->new( tx => $tx );
